==> ui-18.5.2.tgz: package/components/radio/RadioGroupRenderer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { nth } from 'lodash';
import React, { useEffect, useState } from 'react';
import { useId } from '@react-devui/hooks';
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useFormControl } from '../form';
import { useComponentConfig } from '../root';
import { DRadio } from './Radio';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.GroupRenderer' });
export function DRadioGroupRenderer(props) {
    var _a, _b;
    const { dFormControl, dList, dModel, dName, dVerticalCenter = false, dDisabled = false, dRender, onModelChange, } = useComponentConfig(COMPONENT_NAME, props);
    //#region Context
    const { gDisabled } = useGeneralContext();
    //#endregion
    const uniqueId = useId();
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue((_b = (_a = nth(dList, 0)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : null, dModel, onModelChange, undefined, formControlInject);
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return dRender(dList.map((item) => React.cloneElement(_jsx(DRadio, Object.assign({ dModel: item.value === value, dVerticalCenter: dVerticalCenter, dDisabled: item.disabled || disabled, dInputRender: (el) => cloneHTMLElement(el, {
            value: item.value,
            name: dName !== null && dName !== void 0 ? dName : uniqueId,
            ['data-form-item-label-for']: item.value === value,
        }), onModelChange: () => {
            changeValue(item.value);
            setIsChange(true);
        } }, { children: item.label }), item.value))));
}

==> ui-18.6.1.tgz: package/components/radio/RadioGroupRenderer.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { nth } from 'lodash';
import React, { useEffect, useState } from 'react';
import { useId } from '@react-devui/hooks';
import { useGeneralContext, useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { useFormControl } from '../form';
import { useComponentConfig } from '../root';
import { DRadio } from './Radio';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DRadio.GroupRenderer' });
export function DRadioGroupRenderer(props) {
    var _a, _b;
    const { dFormControl, dList, dModel, dName, dDisabled = false, dRender, onModelChange } = useComponentConfig(COMPONENT_NAME, props);
    //#region Context
    const { gDisabled } = useGeneralContext();
    //#endregion
    const uniqueId = useId();
    const formControlInject = useFormControl(dFormControl);
    const [value, changeValue] = useDValue((_b = (_a = nth(dList, 0)) === null || _a === void 0 ? void 0 : _a.value) !== null && _b !== void 0 ? _b : null, dModel, onModelChange, undefined, formControlInject);
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const disabled = dDisabled || gDisabled || (dFormControl === null || dFormControl === void 0 ? void 0 : dFormControl.control.disabled);
    return dRender(dList.map((item) => React.cloneElement(_jsx(DRadio, Object.assign({ dModel: item.value === value, dDisabled: item.disabled || disabled, dInputRender: (el) => cloneHTMLElement(el, {
            value: item.value,
            name: dName !== null && dName !== void 0 ? dName : uniqueId,
            ['data-form-item-label-for']: item.value === value,
        }), onModelChange: () => {
            changeValue(item.value);
            setIsChange(true);
        } }, { children: item.label }), item.value))));
}
